@@ -45,5 +45,4 @@ TEST_CLIMATE_RFATV_2_SET_VALUE = "00 3C 00"
 
 TEST_BUTTON_RFGB_40_TOPIC_STATE = "inels/status/4254524524/19/10904"
 TEST_BUTTON_RFGB_40_TOPIC_CONNECTED = "inels/connected/4254524524/19/10904"
-TEST_BUTTON_RFGB_40_SET_VALUE = "True"
-TEST_BUTTON_RFGB_40_STATE_VALUE = b"True"
+TEST_BUTTON_RFGB_40_STATE_VALUE = b"20\n01\nDA\n23\n54"
